OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Download" : "Herunterladen",
    "Copy link" : "Link kopieren",
    "Click to copy the link to your clipboard" : "Durch klicken wird der Link in die Zwischenablage kopiert",
    "Toggle sharing" : "Freigabe umschalten",
    "Delete" : "Löschen",
    "Rename" : "Umbenennen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Close" : "Schließen",
    "Enabled" : "Aktiviert",
    "Disabled" : "Deaktiviert",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "Address book name" : "Name des Adressbuchs",
    "Only these special characters are allowed: -_.!?#|()" : "Es sind nur die folgenden Sonderzeichen erlaubt: -_.!?#|()",
    "Address book could not be created." : "Adressbuch konnte nicht erstellt werden",
    "The selected image is too big (max 1MB)" : "Das ausgewählte Bild ist zu groß (max. 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Diese Karte ist beschädigt und wurde repariert. Überprüfe die Daten und speichere diese, um die Änderungen dauerhaft zu übernehmen.",
    "No contacts in here" : "Keine Kontakte vorhanden",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field …" : "Feld hinzufügen…",
    "Save changes" : "Änderungen speichern",
    "Address book" : "Adressbuch",
    "Loading contacts …" : "Kontakte laden…",
    "Import into" : "Importieren nach",
    "Importing..." : "Importiere…",
    "Select your addressbook" : "Wähle Dein Adressbuch",
    "Import is disabled because no writable address book had been found." : "Der Import wurde deaktiviert, denn es wurde kein beschreibbares Adressbuch gefunden.",
    "No search result for {query}" : "Keine Suchergebnisse zu {query}",
    "All contacts" : "Alle Kontakte",
    "Post office box" : "Postfach",
    "Postal code" : "Postleitzahl",
    "City" : "Stadt",
    "State or province" : "Bundesland oder Region",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(neue Gruppe)",
    "Last name" : "Nachname",
    "First name" : "Vorname",
    "Additional names" : "Zusätzliche Namen",
    "Prefix" : "Präfix",
    "Suffix" : "Suffix",
    "Importing into" : "Importiere nach",
    "New contact" : "Neuer Kontakt",
    "Not grouped" : "Nicht gruppiert",
    "Sort by" : "Sortiere nach",
    "There is no address book available to create a contact." : "Es ist kein Adressbuch vorhanden um den Kontakt zu erstellen.",
    "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
    "Contact not found." : "Kontakt nicht gefunden.",
    "You don't have permission to write to this addressbook." : "Du hast nicht die Berechtigung um Einträge in diesem Adressbuch vorzunehmen",
    "Contact could not be created." : "Kontakt konnte nicht erstellt werden.",
    "No contacts in file. Only vCard files are allowed." : "Keine Adressen in der Datei. Es kann nur das vCard-Format verarbeitet werden.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Es werden nur vCard-Format 4.0 (RFC6350) oder 3.0 (RFC2426) unterstützt.",
    "Contact could not be moved." : "Kontakt konnte nicht verschoben werden.",
    "Contact could not be saved." : "Kontakt konnte nicht gespeichert werden.",
    "Waiting for the server to be ready…" : "Warte bis der Server bereit ist…",
    "Importing…" : "Importiere…",
    "Display name" : "Anzeigename",
    "Nickname" : "Spitzname",
    "Detailed name" : "Detaillierter Name",
    "Notes" : "Notizen",
    "Website" : "Internetseite",
    "Federated Cloud ID" : "Federated-Cloud-ID",
    "Home" : "Privat",
    "Work" : "Arbeit",
    "Other" : "Andere",
    "Groups" : "Gruppen",
    "Birthday" : "Geburtstag",
    "Anniversary" : "Jahrestag",
    "Date of death" : "Todestag",
    "Email" : "E-Mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Mobil Arbeit",
    "Fax" : "Fax",
    "Fax home" : "Fax privat",
    "Fax work" : "Fax Arbeit",
    "Pager" : "Pager",
    "Voice" : "Anruf",
    "Car" : "Auto",
    "Work pager" : "Pager Arbeit",
    "Social network" : "Soziales Netzwerk",
    "Relationship" : "Beziehung",
    "Spouse" : "Partner",
    "Child" : "Kind",
    "Mother" : "Mutter",
    "Father" : "Vater",
    "Parent" : "Elternteil",
    "Brother" : "Bruder",
    "Sister" : "Schwester",
    "Relative" : "Verwandter",
    "Friend" : "Freund",
    "Colleague" : "Arbeitskollege",
    "Manager" : "Geschäftsleiter",
    "Assistant" : "Assistent",
    "Gender" : "Geschlecht",
    "Female" : "Weiblich",
    "Male" : "Männlich",
    "Details" : "Details",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");
